@@ -12,22 +12,22 @@ from octodns.record import GeoCodes, Record
 from octodns.provider import ProviderException
 from octodns.provider.base import BaseProvider
 
-__VERSION__ = '0.0.1'
+__VERSION__ = '0.0.3'
 
 
 class GCoreClientException(ProviderException):
     def __init__(self, r):
-        super(GCoreClientException, self).__init__(r.text)
+        super().__init__(r.text)
 
 
 class GCoreClientBadRequest(GCoreClientException):
     def __init__(self, r):
-        super(GCoreClientBadRequest, self).__init__(r)
+        super().__init__(r)
 
 
 class GCoreClientNotFound(GCoreClientException):
     def __init__(self, r):
-        super(GCoreClientNotFound, self).__init__(r)
+        super().__init__(r)
 
 
 class GCoreClient(object):
@@ -53,9 +53,7 @@ class GCoreClient(object):
             )
         elif login is not None and password is not None:
             token = self._auth(auth_url, login, password)
-            self._session.headers.update(
-                {"Authorization": f"Bearer {token}"}
-            )
+            self._session.headers.update({"Authorization": f"Bearer {token}"})
         else:
             raise ValueError("either token or login & password must be set")
 
@@ -101,8 +99,9 @@ class GCoreClient(object):
         ).json()
 
     def zone_records(self, zone_name):
-        url = self._build_url(self._api_url, self.ROOT_ZONES, zone_name,
-                              "rrsets")
+        url = self._build_url(
+            self._api_url, self.ROOT_ZONES, zone_name, "rrsets"
+        )
         rrsets = self._request("GET", url, params={"all": "true"}).json()
         records = rrsets["rrsets"]
         return records
@@ -133,22 +132,19 @@ class GCoreClient(object):
         return base
 
 
-class GCoreProvider(BaseProvider):
+class _BaseProvider(BaseProvider):
     SUPPORTS_GEO = False
     SUPPORTS_DYNAMIC = True
     SUPPORTS = set(("A", "AAAA", "NS", "MX", "TXT", "SRV", "CNAME", "PTR"))
 
-    def __init__(self, id, *args, **kwargs):
+    def __init__(self, id, api_url, auth_url, *args, **kwargs):
         token = kwargs.pop("token", None)
         token_type = kwargs.pop("token_type", "APIKey")
         login = kwargs.pop("login", None)
         password = kwargs.pop("password", None)
-        api_url = kwargs.pop("url", "https://dnsapi.gcorelabs.com/v2")
-        auth_url = kwargs.pop("auth_url", "https://api.gcdn.co")
         self.records_per_response = kwargs.pop("records_per_response", 1)
-        self.log = logging.getLogger(f"GCoreProvider[{id}]")
         self.log.debug("__init__: id=%s", id)
-        super(GCoreProvider, self).__init__(id, *args, **kwargs)
+        super().__init__(id, *args, **kwargs)
         self._client = GCoreClient(
             self.log,
             api_url,
@@ -281,11 +277,7 @@ class GCoreProvider(BaseProvider):
                     for rr_value in resource_record["content"]
                 ]
             }
-        return {
-            "ttl": record["ttl"],
-            "type": _type,
-            **extra,
-        }
+        return {"ttl": record["ttl"], "type": _type, **extra}
 
     _data_for_A = _data_for_multiple
     _data_for_AAAA = _data_for_multiple
@@ -506,10 +498,7 @@ class GCoreProvider(BaseProvider):
             extra["resource_records"] = [
                 {"content": [value]} for value in record.values
             ]
-        return {
-            "ttl": record.ttl,
-            **extra,
-        }
+        return {"ttl": record.ttl, **extra}
 
     _params_for_A = _params_for_multiple
     _params_for_AAAA = _params_for_multiple
@@ -587,8 +576,22 @@ class GCoreProvider(BaseProvider):
             self._client.zone_create(zone)
             self.log.info("_apply: zone has been successfully created")
 
-        changes.reverse()
-
         for change in changes:
             class_name = change.__class__.__name__
             getattr(self, f"_apply_{class_name.lower()}")(change)
+
+
+class EdgeCenterProvider(_BaseProvider):
+    def __init__(self, id, *args, **kwargs):
+        self.log = logging.getLogger(f"EdgeCenterProvider[{id}]")
+        api_url = kwargs.pop("url", "https://api.edgecenter.ru/dns/v2")
+        auth_url = kwargs.pop("auth_url", "https://api.edgecenter.ru/id")
+        super().__init__(id, api_url, auth_url, *args, **kwargs)
+
+
+class GCoreProvider(_BaseProvider):
+    def __init__(self, id, *args, **kwargs):
+        self.log = logging.getLogger(f"GCoreProvider[{id}]")
+        api_url = kwargs.pop("url", "https://api.gcorelabs.com/dns/v2")
+        auth_url = kwargs.pop("auth_url", "https://api.gcorelabs.com/id")
+        super().__init__(id, api_url, auth_url, *args, **kwargs)
